==> next-ft-api-client-3.23.0.tgz: package/test/things.test.js <==
/*eslint no-unused-vars:0 */
/*global describe, beforeEach, it */

'use strict';

GLOBAL.fetch = require('node-fetch');

const nock = require('nock');
const expect = require('chai').expect;
const subject = require('../src/things');

const fixtureFound = require('./fixtures/es-interface-things');
const fixtureEmpty = require('./fixtures/es-interface-things-empty');

describe('Things', () => {

	describe('results found', () => {

		let result;
		let request;

		beforeEach(() => {
			const data = {
				"identifierValues": ["TnN0ZWluX0dMX0V1cm9wZQ==-R0w=","TnN0ZWluX0dMX0dC-R0w=","TnN0ZWluX0dMX1VT-R0w="],
				"authority": "http://api.ft.com/system/FT-TME"
			};

			request = nock('https://ft-next-es-interface-eu.herokuapp.com')
				.post('/things', data)
				.reply(200, fixtureFound);

			return subject(data).then(d => result = d);
		});

		it('returns an array of source terms', () => {
			expect(result).to.be.an.instanceof(Object);
			expect(result.items).to.be.an.instanceof(Array);

			result.items.forEach(item => {
				expect(item).not.to.include.keys('term', 'body');
			});
		});

		it('appends total search result count', () => {
			expect(result.total).to.equal(fixtureFound.length);
		});

	});

	describe('results empty', () => {

		let result;
		let request;

		beforeEach(() => {
			request = nock('https://ft-next-es-interface-eu.herokuapp.com',{allowUnmocked: true})
				.post('/things')
				.reply(200, fixtureEmpty);

			return subject({
				"identifierValues": ["TnN0ZWluX0dMX0V1cm9wZQ==-R0w=dsdd"],
				"authority": "http://api.ft.com/system/FT-TME"
			}).then(data => result = data);
		});

		it('returns an empty array', () => {
			expect(result).to.be.an.instanceof(Object);
			expect(result.items).to.be.an.instanceof(Array);
			expect(result.items).to.have.length(0);
		});

		it('appends total search result count', () => {
			expect(result.total).to.equal(0);
		});

	});

});

==> next-ft-api-client-3.25.0.tgz: package/test/things.test.js <==
/*eslint no-unused-vars:0 */
/*global describe, beforeEach, it */

'use strict';

GLOBAL.fetch = require('node-fetch');

const nock = require('nock');
const expect = require('chai').expect;
const subject = require('../src/things');

const fixtureFound = require('./fixtures/es-v3-topics-search-found.json');
const fixtureEmpty = require('./fixtures/es-interface-things-empty');

describe('Things', () => {

	describe('results found', () => {

		let result;
		let request;
		let data;

		beforeEach(() => {
			data = {
				"identifierValues": ["Mg==-R2VucmVz", "ZWI2YTE0YjgtOTIyYy00OTIyLWExOTYtZmRmNzk0YzA4NGFk-QnJhbmRz", "Mg==-R2VucmVz"]
			};

			request = nock('https://next-elastic.ft.com')
				.post('/v3_api_v2/item/_search')
				.times(3)
				.reply(200, fixtureFound);

			return subject(data).then(d => result = d);
		});

		it('returns an array of source terms', () => {
			expect(result).to.be.an.instanceof(Object);
			expect(result.items).to.be.an.instanceof(Array);

			result.items.forEach(item => {
				expect(item).not.to.include.keys('term', 'body');
			});
		});

		it('appends total search result count', () => {
			expect(result.total).to.equal(data.identifierValues.length);
		});

	});

	describe('results empty', () => {

		let result;
		let request;

		beforeEach(() => {
			request = nock('https://ft-next-es-interface-eu.herokuapp.com',{allowUnmocked: true})
				.post('/things')
				.reply(200, fixtureEmpty);

			return subject({
				"identifierValues": ["TnN0ZWluX0dMX0V1cm9wZQ==-R0w=dsdd"],
				"authority": "http://api.ft.com/system/FT-TME"
			}).then(data => result = data);
		});

		it('returns an empty array', () => {
			expect(result).to.be.an.instanceof(Object);
			expect(result.items).to.be.an.instanceof(Array);
			expect(result.items).to.have.length(0);
		});

		it('appends total search result count', () => {
			expect(result.total).to.equal(0);
		});

	});

});
